//---------------------------------------------------------------------------
// GPGee - GNU Privacy Guard Explorer Extension
// GPGeeSignEncrypt.h - 'Main' form code header
// Copyright 2005, Kurt Fitzner <kfitzner@excelcia.org>
//---------------------------------------------------------------------------
// This file is part of GPGee.
//
// GPGee is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// GPGee is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
//---------------------------------------------------------------------------
#ifndef GPGeeSignEncryptH
#define GPGeeSignEncryptH
//---------------------------------------------------------------------------
#include "gpgme/gpgme.h"
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Grids.hpp>
#include <ExtCtrls.hpp>
#include <Buttons.hpp>
#include <ComCtrls.hpp>
//---------------------------------------------------------------------------
class TformGPGeeSignEncrypt : public TForm
{
__published:	// IDE-managed Components
  TPanel *pnlClient;
  TLabel *lblSigningKey;
  TComboBox *cbSigningKey;
  TRadioGroup *rgEncryptionOptions;
  TGroupBox *gbMiscOptions;
  TCheckBox *chbASCIIArmor;
  TButton *btnOk;
  TButton *btnCancel;
  TListView *lvPublicKeys;
  TGroupBox *gbSignatureOptions;
  TRadioButton *radioNoSignature;
  TRadioButton *radioAttached;
  TRadioButton *radioDetached;
  TCheckBox *chbClearsign;
  TButton *btnHelp;

  void __fastcall FormActivate(TObject *Sender);
  void __fastcall FormFirstActivation(TObject *Sender);
  void __fastcall lvPublicKeysColumnClick(TObject *Sender, TListColumn *Column);
  void __fastcall SanityCheck(TObject *Sender);
  void __fastcall lvPublicKeysChanging(TObject *Sender, TListItem *Item, TItemChange Change, bool &AllowChange);
  void __fastcall lvPublicKeysChange(TObject *Sender, TListItem *Item, TItemChange Change);
  void __fastcall btnOkClick(TObject *Sender);
  void __fastcall btnHelpClick(TObject *Sender);

private:	// User declarations
  bool              bFirstActivation;                 // Is this the first time the form is being activated since construction?
  AnsiString        sBinDir;                          // The directory where the DLL is located
  gpgme_ctx_t       ctxGPG;                           // GPGME context
  gpgme_keycache_t  cachePublic;                      // Public key cache
  gpgme_keycache_t  cacheSecret;                      // Secret key cache
  bool              bStartupSign, bStartupEncrypt;    // Store our startup default settings here
  TStringList       *FileNames;                       // Store the filenames for all the files we're operating on
  int               nEncryptCount;                    // The number of keys the user has selected to encrypt to

  AnsiString        sGPGPath;
  AnsiString        sOptfile;
  AnsiString        sKeyring;
  AnsiString        sSecretKeyring;
  bool              bForceTrustMode;

  void __fastcall ReadDefaults(void);

public:		// User declarations
  __fastcall TformGPGeeSignEncrypt(TComponent* Owner);
  __fastcall ~TformGPGeeSignEncrypt();
  int __fastcall ShowModalWithDefaults(bool bSign, bool bEncrypt, TStringList *FileNames);
};

int __stdcall SortByColumn(long Item1, long Item2, long Data);
static int  pubkeysLastSorted;
static bool pubkeysAscending;

#define GPGEE_ENCRYPTION_NONE 0
#define GPGEE_ENCRYPTION_PUBLIC 1
#define GPGEE_ENCRYPTION_SYMMETRIC 2

//---------------------------------------------------------------------------
extern PACKAGE TformGPGeeSignEncrypt *formGPGeeSignEncrypt;
//---------------------------------------------------------------------------
#endif
